@@ -180,9 +180,9 @@ class MonitorJobSite:
 
 
    def configure(self):
-      sectionPattern  = re.compile('(\s*\[)([^\s]*)(]\s*)')
-      keyValuePattern = re.compile('( *)(\w*)( *= *)(.*[^\s$])( *)')
-      commentPattern  = re.compile('\s*#.*')
+      sectionPattern  = re.compile(r'(\s*\[)([^\s]*)(]\s*)')
+      keyValuePattern = re.compile(r'( *)(\w*)( *= *)(.*[^\s$])( *)')
+      commentPattern  = re.compile(r'\s*#.*')
       inMonitorSection = False
 
       configured = False
@@ -217,23 +217,30 @@ class MonitorJobSite:
                               self.configData[key] = int(value)
                            elif isinstance(self.configData[key],dict):
                               try:
-                                 sampleKey   = self.configData[key].keys()[0]
+                                 sampleKey   = list(self.configData[key].keys())[0]
                                  sampleValue = self.configData[key][sampleKey]
                               except:
-                                 sampleKey   = "key"
-                                 sampleValue = "value"
-                              self.configData[key] = {}
-                              for e in value.split(','):
-                                 dictKey,dictValue = e.split(':')
-                                 if isinstance(sampleKey,int):
-                                    dictKey = int(dictKey)
-                                 if   isinstance(sampleValue,int):
-                                    dictValue = int(dictValue)
-                                 elif isinstance(sampleValue,float):
-                                    dictValue = float(dictValue)
-                                 elif isinstance(sampleValue,bool):
-                                    dictValue = bool(dictValue.lower() == 'true')
-                                 self.configData[key][dictKey] = dictValue
+                                 try:
+                                    self.configData[key] = json.loads(value)
+                                 except:
+                                    self.configData[key] = {}
+                                    sampleKey   = "key"
+                                    sampleValue = "value"
+                              else:
+                                 self.configData[key] = {}
+               
+                              if not self.configData[key]:
+                                 for e in value.split(','):
+                                    dictKey,dictValue = e.split(':')
+                                    if isinstance(sampleKey,int):
+                                       dictKey = int(dictKey)
+                                    if   isinstance(sampleValue,int):
+                                       dictValue = int(dictValue)
+                                    elif isinstance(sampleValue,float):
+                                       dictValue = float(dictValue)
+                                    elif isinstance(sampleValue,bool):
+                                       dictValue = bool(dictValue.lower() == 'true')
+                                    self.configData[key][dictKey] = dictValue
                            else:
                               self.configData[key] = value
                         else:
